#!/bin/bash

# Charger les variables de l'environnement
source /var/www/html/sauvegardeBdd/.env.local
BACKUP_FILE="backup_$DATE_FILESAVE.sql" # Définir le nom du fichier de sauvegarde (partie export)
CHECKSUM_FILE="$BACKUP_FILE.gpg.sha256" # Définir le nom du fichier pour vérifier l'intégrité (partie intégrité)

# Si le gpg n'est pas configuré
# Générer les clés
    gpg --batch --full-generate-key gpg_key_config.conf

# Exporter les clés
    gpg --export-secret-keys -o "$KEY_DIR/cle_privee.asc"
    gpg --export-secret-keys -o "$KEY_DIR/cle_publique.asc"

# Se placer dans le dossier de destination
    cd $BACKUP_DIR

# Exportation de la BDD
    mysqldump -u"$DB_USER" -p"$DB_PASSWORD" "$DB_NAME" > "$BACKUP_DIR/$BACKUP_FILE"

# Chiffrer le fichier
    gpg --yes --encrypt --recipient "$EMAIL_OWNERBDD" "$BACKUP_DIR/$BACKUP_FILE"
    rm $BACKUP_FILE

# Générer la somme de contrôle du fichier chiffré
    sha256sum "$BACKUP_DIR/$BACKUP_FILE.gpg" > "$BACKUP_DIR/$CHECKSUM_FILE"

# Vérification de l'intégrité du fichier chiffré
    if sha256sum -c "$BACKUP_FILE.gpg.sha256"; then
        echo "Le fichier chiffré (avant transfert) est intègre."
    else
        echo "Le fichier chiffré (avant transfert) a été corrompu."
        exit 1
    fi

# Transfert du fichier chiffré et du fichier qui justifie l'intégrité du fichier chiffré
    scp "$BACKUP_DIR/$BACKUP_FILE.gpg" "$DB_USER_B@$IP_MACH_B:$BACKUP_DIR_B/"
    scp "$BACKUP_DIR/$CHECKSUM_FILE" "$DB_USER_B@$IP_MACH_B:$BACKUP_DIR_B/"

# Détruire les clés (en temps normal ça c'est après le transfert et le déchiffrement sur l'autre machine)
    shred -u "$KEY_DIR/cle_privee.asc"
    shred -u "$KEY_DIR/cle_publique.asc"